@@ -1,4 +1,5 @@
 # -*- coding: utf8 -*-
+
 from nr.databind.core import Field, Struct
 from nr.interface import implements, override
 from pathlib import Path
@@ -7,8 +8,11 @@ from pydoc_markdown.contrib.renderers.markdown import MarkdownRenderer
 from typing import Any, Dict, List, Text
 import docspec
 import json
+import logging
 import os.path
 
+logger = logging.getLogger(__name__)
+
 
 class CustomizedMarkdownRenderer(MarkdownRenderer):
   """We override some defaults in this subclass. """
@@ -22,7 +26,7 @@ class CustomizedMarkdownRenderer(MarkdownRenderer):
   #: Conforms to Docusaurus header format.
   render_module_header_template = Field(str, default=(
     '---\n'
-    'sidebar_label: {module_name}\n'
+    'sidebar_label: {relative_module_name}\n'
     'title: {module_name}\n'
     '---\n\n'
   ))
@@ -58,9 +62,13 @@ class DocusaurusRenderer(Struct):
   relative_sidebar_path = Field(str, default='sidebar.json')
 
   #: The top-level label in the sidebar. Default to 'Reference'. Can be set to null to
-  #: remove the sidebar top-level all together.
+  #: remove the sidebar top-level all together. This option assumes that there is only one top-level module.
   sidebar_top_level_label = Field(str, default='Reference', nullable=True)
 
+  #: The top-level module label in the sidebar. Default to null, meaning that the actual
+  #: module name will be used. This option assumes that there is only one top-level module.
+  sidebar_top_level_module_label = Field(str, default=None, nullable=True)
+
   @override
   def render(self, modules: List[docspec.Module]) -> None:
     modules_and_paths = []
@@ -70,6 +78,9 @@ class DocusaurusRenderer(Struct):
       filepath = output_path
 
       module_parts = module.name.split(".")
+      if module.location.filename.endswith("__init__.py"):
+        module_parts.append("__init__")
+
       relative_module_tree = module_tree
       intermediary_module = []
 
@@ -88,6 +99,7 @@ class DocusaurusRenderer(Struct):
       filepath = filepath / f"{module_parts[-1]}.md"
 
       with filepath.open('w') as fp:
+        logger.info("Render file %s", filepath)
         self.markdown.render_to_stream([module], fp)
 
       # only update the relative module tree if the file is not empty
@@ -108,11 +120,19 @@ class DocusaurusRenderer(Struct):
       "label": self.sidebar_top_level_label,
     }
     self._build_sidebar_tree(sidebar, module_tree)
-    if not self.sidebar_top_level_label:
-      sidebar = sidebar['items']
+
+    if sidebar.get("items"):
+      if self.sidebar_top_level_module_label:
+        sidebar['items'][0]["label"] = self.sidebar_top_level_module_label
+
+      if not self.sidebar_top_level_label:
+        # it needs to be a dictionary, not a list; this assumes that
+        # there is only one top-level module
+        sidebar = sidebar['items'][0]
 
     sidebar_path = Path(self.docs_base_path) / self.relative_output_path / self.relative_sidebar_path
     with sidebar_path.open("w") as handle:
+      logger.info("Render file %s", sidebar_path)
       json.dump(sidebar, handle, indent=2, sort_keys=True)
 
   def _build_sidebar_tree(self, sidebar: Dict[Text, Any], module_tree: Dict[Text, Any]) -> None:
